use once_cell::sync::OnceCell;

use reqwest::Client;
use rocket::{http::Status, serde::json::Json};
use serde::{Deserialize, Serialize};

use self::session::ensure_session;

pub mod json_result;
mod session;
pub mod users;



#[derive(Debug, Serialize, Deserialize)]
pub enum ConnectionResult {
    Ok(),
    Error(ConnectionError),
}
#[derive(Debug, Serialize, Deserialize)]
pub struct ConnectionError {
    reason: String,
}
fn new_error(reason: String) -> ConnectionResult {
    ConnectionResult::Error(ConnectionError { reason })
}

/// Tries to connect to the online classroom, and get a session cookie
#[get("/classroom/connect")]
pub async fn connection() -> (Status, Json<ConnectionResult>) {
    match ensure_session().await {
        Ok(_) => (Status::Ok, Json(ConnectionResult::Ok())),
        Err(err) => (Status::Ok, Json(new_error(err))),
    }
}


